@@ -131,7 +131,7 @@ class Configurator:
 
 
     def writeConfig(self):
-        outputXMLFile = codecs.open(self._outputFile, mode='w', encoding='latin-1')
+        outputXMLFile = codecs.open(self._outputFile, mode='w', encoding='utf8')
         outputXMLFile.write(self.config.toxml())
         outputXMLFile.close()
         logger.reportInfo('Output config written to ' + self._outputFile)
